==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A>> extends BaseFluent<A>{
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent() {
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    instance = (instance != null ? instance : new ConnectionPoolSettingsTCPSettingsTcpKeepalive());

    if (instance != null) {
      this.withInterval(instance.getInterval());
      this.withProbes(instance.getProbes());
      this.withTime(instance.getTime());
      this.withInterval(instance.getInterval());
      this.withProbes(instance.getProbes());
      this.withTime(instance.getTime());
    }
  }
  private String interval;
  private Integer probes;
  private String time;
  public String getInterval() {
    return this.interval;
  }
  public A withInterval(String interval) {
    this.interval=interval; return (A) this;
  }
  public boolean hasInterval() {
    return this.interval != null;
  }
  public Integer getProbes() {
    return this.probes;
  }
  public A withProbes(Integer probes) {
    this.probes=probes; return (A) this;
  }
  public boolean hasProbes() {
    return this.probes != null;
  }
  public String getTime() {
    return this.time;
  }
  public A withTime(String time) {
    this.time=time; return (A) this;
  }
  public boolean hasTime() {
    return this.time != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent that = (ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent) o;
    if (!java.util.Objects.equals(interval, that.interval)) return false;

    if (!java.util.Objects.equals(probes, that.probes)) return false;

    if (!java.util.Objects.equals(time, that.time)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(interval,  probes,  time,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (interval != null) { sb.append("interval:"); sb.append(interval + ","); }
    if (probes != null) { sb.append("probes:"); sb.append(probes + ","); }
    if (time != null) { sb.append("time:"); sb.append(time); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent<A>> extends BaseFluent<A>{
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent() {
  }
  
  public ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    this.copyInstance(instance);
  }
  private String interval;
  private Integer probes;
  private String time;
  
  protected void copyInstance(ConnectionPoolSettingsTCPSettingsTcpKeepalive instance) {
    instance = (instance != null ? instance : new ConnectionPoolSettingsTCPSettingsTcpKeepalive());
  
    if (instance != null) {
        this.withInterval(instance.getInterval());
        this.withProbes(instance.getProbes());
        this.withTime(instance.getTime());
        this.withInterval(instance.getInterval());
        this.withProbes(instance.getProbes());
        this.withTime(instance.getTime());
      }
  }
  
  public String getInterval() {
    return this.interval;
  }
  
  public A withInterval(String interval) {
    this.interval=interval; return (A) this;
  }
  
  public boolean hasInterval() {
    return this.interval != null;
  }
  
  public Integer getProbes() {
    return this.probes;
  }
  
  public A withProbes(Integer probes) {
    this.probes=probes; return (A) this;
  }
  
  public boolean hasProbes() {
    return this.probes != null;
  }
  
  public String getTime() {
    return this.time;
  }
  
  public A withTime(String time) {
    this.time=time; return (A) this;
  }
  
  public boolean hasTime() {
    return this.time != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent that = (ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluent) o;
    if (!java.util.Objects.equals(interval, that.interval)) return false;
  
    if (!java.util.Objects.equals(probes, that.probes)) return false;
  
    if (!java.util.Objects.equals(time, that.time)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(interval,  probes,  time,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (interval != null) { sb.append("interval:"); sb.append(interval + ","); }
    if (probes != null) { sb.append("probes:"); sb.append(probes + ","); }
    if (time != null) { sb.append("time:"); sb.append(time); }
    sb.append("}");
    return sb.toString();
  }
  

}
